@@ -114,11 +114,10 @@ class WinOSClient:
 
     def __init__(
             self,
-            host: str = '',
-            username: str = '',
-            password: str = '',
-            logger_enabled: bool = True,
-    ):
+            host: str = None,
+            username: str = None,
+            password: str = None,
+            logger_enabled: bool = True):
 
         self.host = host
         self.username = username
@@ -211,7 +210,7 @@ class WinOSClient:
         response = None
 
         try:
-            logger.info('[COMMAND] ' + command)
+            logger.info(f'[{self.host}] ' + command)
             if ps:  # Use PowerShell
                 endpoint = (f'https://{self.host}:5986/wsman'
                             if use_cred_ssp
@@ -224,7 +223,8 @@ class WinOSClient:
                     endpoint=f'http://{self.host}:5985/wsman',
                     transport='ntlm')
                 response = client.run_cmd(command, [arg for arg in args])
-            return ResponseParser(response)
+            # return ResponseParser(response)
+            return response
 
         # Catch exceptions
         except InvalidCredentialsError as err:
@@ -307,7 +307,7 @@ class WinOSClient:
 
         with Popen(cmd, shell=True, stdout=PIPE, stderr=PIPE) as process:
             try:
-                logger.info('[COMMAND] ' + cmd)
+                logger.info('[LOCAL CMD] ' + cmd)
                 stdout, stderr = process.communicate(timeout=timeout)
                 exitcode = process.wait(timeout=timeout)
                 response = exitcode, stdout, stderr
@@ -519,45 +519,39 @@ class WinOSClient:
                 m.update(data)
             return m.hexdigest()
 
-    @staticmethod
-    def clean_directory(path: str):
+    def clean_directory(self, path: str, ignore_errors: bool = False):
         """Clean (remove) all files from a windows directory
 
         :param path: Full file\\directory path
         """
 
-        try:
-            for the_file in os.listdir(path):
-                file_path = os.path.join(path, the_file)
-                basename = os.path.basename(file_path)
-
-                if os.path.isfile(file_path):
-                    if basename != 'pagefile.sys':
-                        os.remove(file_path)
-                elif os.path.isdir(file_path):
-                    if basename != 'System Volume Information':
-                        shutil.rmtree(file_path)
-            return True
-        except OSError as e:
-            print(f'The user name or password to {path} is incorrect', e)
-            raise e
+        for the_file in os.listdir(path):
+            file_path = os.path.join(path, the_file)
+            self.remove(file_path, ignore_errors=ignore_errors)
+        return True
 
     @staticmethod
-    def remove(path: str) -> bool:
+    def remove(path: str, ignore_errors: bool = False) -> bool:
         """Remove file or directory recursively
 
         :param path: Full file\\directory path
+        :param ignore_errors: If ignore_errors is set, errors are ignored. Used for directory only
         """
 
         try:
             if os.path.isfile(path):
                 os.remove(path)
-            elif os.path.isdir(path):
-                shutil.rmtree(path)
+            else:
+                shutil.rmtree(path, ignore_errors=ignore_errors)
             return True
-        except OSError as e:
-            print(f'The user name or password to {path} is incorrect', e)
-            return False
+        except PermissionError as err:
+            logger.error(err)
+            if not ignore_errors:
+                raise err
+        except OSError as err:
+            logger.error(err)
+            if not ignore_errors:
+                raise err
 
     def copy(self, source: str, destination: str, new_name=None):
         """Copy file to a remote windows directory.
@@ -639,10 +633,15 @@ class WinOSClient:
 
     # ---------- Service / process management ----------
     def get_service(self, name: str):
-        """Check windows service status"""
+        """Check windows service"""
 
         return self.run_ps(f'Get-Service -Name {name}')
 
+    def get_service_status(self, name: str):
+        """Check windows service status"""
+
+        return self.run_ps(f'(Get-Service -Name {name}).Status')
+
     def start_service(self, name: str):
         """Start service"""
         return self.run_ps(f'Start-Service -Name {name}')
